********************
Third-Party Projects
********************

Below are links to third-party projects that use :rst:dir:`autoclasstoc` in 
their documentation.  Hopefully these examples are useful both to show what 
:rst:dir:`autoclasstoc` looks like "in the wild", and to provide inspiration 
for your own documentation:

- `Glooey <https://glooey.readthedocs.io/en/latest/>`__
- `KXG Game Engine <https://kxg-game-engine.readthedocs.io/en/latest/>`__
